changeset 25800:609695887d08

(image_error): Use add_to_log.
author Gerd Moellmann <gerd@gnu.org>
date Thu, 23 Sep 1999 22:17:46 +0000
parents 1c370ec939da
children 8f6d4157f700
files src/xfns.c
diffstat 1 files changed, 6 insertions(+), 11 deletions(-) [+]
line wrap: on
line diff
--- a/src/xfns.c	Thu Sep 23 22:17:44 1999 +0000
+++ b/src/xfns.c	Thu Sep 23 22:17:46 1999 +0000
@@ -5524,23 +5524,18 @@
 }
 
 
-/* Display an error message with format string FORMAT and argument
-   ARG.  Signaling an error, e.g. when an image cannot be loaded,
-   is not a good idea because this would interrupt redisplay, and
-   the error message display would lead to another redisplay.  This
-   function therefore simply displays a message.  */
+/* Log error message with format string FORMAT and argument ARG.
+   Signaling an error, e.g. when an image cannot be loaded, is not a
+   good idea because this would interrupt redisplay, and the error
+   message display would lead to another redisplay.  This function
+   therefore simply displays a message.  */
 
 static void
 image_error (format, arg1, arg2)
      char *format;
      Lisp_Object arg1, arg2;
 {
-  Lisp_Object args[3];
-
-  args[0] = build_string (format);
-  args[1] = arg1;
-  args[2] = arg2;
-  Fmessage (make_number (DIM (args)), args);
+  add_to_log (format, arg1, arg2);
 }